import logging

from django.core.management.base import BaseCommand
from django.contrib.auth import load_backend, login
from django.contrib.auth.backends import RemoteUserBackend
from django.contrib.auth import get_user_model
import django.conf


class Command(BaseCommand):
	can_import_settings = True
	help = 'Synchronize users from a LDAP server'

	def handle(self, *args, **options):
		ldap_backend = load_backend('django_auth_ldap.backend.LDAPBackend')
		conn = ldap_backend.ldap.initialize(ldap_backend.settings.SERVER_URI, bytes_mode=False)
		for opt, value in ldap_backend.settings.CONNECTION_OPTIONS.items():
			conn.set_option(opt, value)
		if ldap_backend.settings.START_TLS:
			conn.start_tls_s()
		conn.simple_bind_s(ldap_backend.settings.BIND_DN, ldap_backend.settings.BIND_PASSWORD)

		user_search = django.conf.settings.AUTH_LDAP_USER_SEARCH_ALL_NAME
		results = user_search.execute(conn)
		ldap_users = [list(attr.values())[0][0] for dn, attr in results ]
		django_users = get_user_model().objects.all()

		for user in ldap_users:
			ldap_backend.populate_user(user).save()
		for user in django_users:
			if not user.username in ldap_users:
				user.delete()
